# Smooth

```sh
automesh smooth --help
<!-- cmdrun automesh smooth --help -->
```

## Smooth Hex

```sh
automesh smooth hex --help
<!-- cmdrun automesh smooth hex --help -->
```

## Smooth Tri

```sh
automesh smooth tri --help
<!-- cmdrun automesh smooth tri --help -->
```
